==> sqfentity_gen-1.0.1.tar.gz: lib/src/sqfentity_generator.dart <==
// Copyright (c) 2018, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:analyzer/dart/element/element.dart';
import 'package:build/build.dart';
import 'package:source_gen/source_gen.dart';
import '../sqfentity_gen.dart';

//import 'package:sqfentity_base/sqfentity_base.dart';

class SqfEntityGenerator extends GeneratorForAnnotation<SqfEntityBuilder> {
  @override
  String generateForAnnotatedElement(
      Element element, ConstantReader annotation, BuildStep buildStep) {
    final model = annotation.read('model').objectValue;

// When testing, you can uncomment the test line to make sure everything's working properly
// return '// MODEL -> ${model.toString()}';

    var instanceName =
        element.toString().replaceAll('SqfEntityModel', '').trim();
    instanceName =
        '${instanceName.substring(0, 1).toUpperCase()}${instanceName.substring(1)}';

    final builder = SqfEntityModelBuilder(model, instanceName);
    final dbModel = builder.toModel();
    final modelStr = StringBuffer()
          //  ..writeln('/*') // write output as commented to see what is wrong
          ..writeln(SqfEntityConverter(dbModel).createModelDatabase())
          ..writeln(SqfEntityConverter(dbModel).createEntites())
        //..writeln('*/') //  write output as commented to see what is wrong
        ;
    return modelStr.toString();
  }
}

==> sqfentity_gen-1.0.2.tar.gz: lib/src/sqfentity_generator.dart <==
// Copyright (c) 2018, the Dart project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'package:analyzer/dart/element/element.dart';
import 'package:build/build.dart';
import 'package:source_gen/source_gen.dart';
import '../sqfentity_gen.dart';

//import 'package:sqfentity_base/sqfentity_base.dart';

class SqfEntityGenerator extends GeneratorForAnnotation<SqfEntityBuilder> {
  @override
  String generateForAnnotatedElement(
      Element element, ConstantReader annotation, BuildStep buildStep) {
    final model = annotation.read('model').objectValue;

// When testing, you can uncomment the test line to make sure everything's working properly
// return '// MODEL -> ${model.toString()}';

    var instanceName =
        element.toString().replaceAll('SqfEntityModel', '').trim();
    instanceName =
        '${instanceName.substring(0, 1).toUpperCase()}${instanceName.substring(1)}';

    final builder = SqfEntityModelBuilder(model, instanceName);
    final dbModel = builder.toModel();
    print('${dbModel.databaseName} recognized succesfuly');
    final modelStr = MyStringBuffer()
          //  ..writeln('/*') // write output as commented to see what is wrong
          ..writeln(SqfEntityConverter(dbModel).createModelDatabase())
          ..printToDebug('${dbModel.databaseName} converted to Db Model successfuly')
          ..writeln(SqfEntityConverter(dbModel).createEntites())
          ..printToDebug('${dbModel.databaseName} converted to Entities successfuly')
        //..writeln('*/') //  write output as commented to see what is wrong
        ;
    return modelStr.toString();
  }
}

class MyStringBuffer extends StringBuffer{

  void printToDebug(String text)
  {
    print(text);
  }
}
